@@ -53,7 +53,7 @@ class NxPyDocs():
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if self.filetype:
+                if self.filetype != "none":
                     if self.repo != "none":
                         self.clone()
                         self.pick_filetype(parsed_json)
@@ -77,11 +77,16 @@ class NxPyDocs():
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
                 if self.filetype != "json" or "yaml":
+                    command_output = clid( '%s' % self.command )
+                    parsed_json = json.loads(command_output)                    
                     if self.repo != "none":
-                        self.clone()
-                        self.pick_filetype(parsed_json)
-                        self.send_to_repo()
-                        self.cleanup()                    
+                        if self.filetype == "none":
+                            click.secho("If you select a repository you must select a filetype")
+                        else:
+                            self.clone()
+                            self.pick_filetype(parsed_json)
+                            self.send_to_repo()
+                            self.cleanup()                    
                     else: 
                         command_output = clid( '%s' % self.command )
                         parsed_json = json.loads(command_output)
